@@ -133,7 +133,8 @@ VALUE_TYPE_ENUM = Enum(Int32ul,
                        REG_RESOURCE_LIST=8,
                        REG_FULL_RESOURCE_DESCRIPTOR=9,
                        REG_RESOURCE_REQUIREMENTS_LIST=10,
-                       REG_QWORD=11)
+                       REG_QWORD=11,
+                       REG_FILETIME=16)
 
 VALUE_KEY = Struct(
     'signature' / Const(b'vk'),
